@@ -3,6 +3,7 @@
 This gives an easy way to download all files from an order
 """
 import logging
+import tempfile
 from typing import List, Optional
 
 import cfgrib
@@ -13,6 +14,7 @@ import s3fs
 import xarray as xr
 
 from metofficedatahub.base import BaseMetOfficeDataHub
+from metofficedatahub.utils import add_x_y, post_process_dataset
 
 logger = logging.getLogger(__name__)
 
@@ -26,6 +28,8 @@ VARS_TO_DELETE = (
     "surface",
     "meanSea",
     "level",
+    "latitude",
+    "longitude",
 )
 
 
@@ -86,6 +90,13 @@ class MetOfficeDataHub(BaseMetOfficeDataHub):
             variable = variable.split("_")[1]
 
             dataset = self.load_file(file=file.local_filename)
+
+            # remove un-needed variables
+            for var in VARS_TO_DELETE:
+
+                if var in dataset.variables:
+                    del dataset[var]
+
             if variable not in all_datasets_per_filename.keys():
                 all_datasets_per_filename[variable] = [dataset]
             else:
@@ -95,19 +106,20 @@ class MetOfficeDataHub(BaseMetOfficeDataHub):
         all_dataset = []
         for k, v in all_datasets_per_filename.items():
 
-            # join all variables toegther
-            dataset = xr.concat(v, dim="step")
+            # add time as dimension
+            v = [vv.expand_dims("time") for vv in v]
 
-            # remove un-needed variables
-            for var in VARS_TO_DELETE:
-                if var in dataset.variables:
-                    del dataset[var]
+            # join all variables together
+            dataset = xr.merge(v)
 
             all_dataset.append(dataset)
 
         dataset = xr.merge(all_dataset)
         logger.debug("Loaded all files")
 
+        dataset = add_x_y(dataset)
+        dataset = post_process_dataset(dataset)
+
         return dataset
 
 
@@ -131,7 +143,7 @@ def make_output_filenames(
     assert output_type in ["zarr", "netcdf"]
 
     # get time of predictions
-    time = pd.to_datetime(dataset.time.values)
+    time = pd.to_datetime(dataset.init_time.values)
 
     # if there are multiple times, just select the first one
     if type(time) == pd.DatetimeIndex:
@@ -140,16 +152,16 @@ def make_output_filenames(
     # make file names
     filename = time.tz_localize("UTC").isoformat()
     filename_and_path = f"{save_dir}/{filename}.{output_type}"
-    filename_and_path_latest = f"{save_dir}/latest.{output_type}/"
+    filename_and_path_latest = f"{save_dir}/latest.{output_type}"
 
     # extra step needed if we are saving to AWS.
     # There may be different steps if saving to different file systems
-    if fsspec.open(save_dir).fs == s3fs.S3FileSystem():
+    if fsspec.open(save_dir).fs == s3fs.S3FileSystem() and output_type == "zarr":
         filename_and_path = fsspec.get_mapper(
-            filename_and_path, client_kwargs={"region_name": "eu-central-1"}
+            filename_and_path, client_kwargs={"region_name": "eu-west-1"}
         )
         filename_and_path_latest = fsspec.get_mapper(
-            filename_and_path_latest, client_kwargs={"region_name": "eu-central-1"}
+            filename_and_path_latest, client_kwargs={"region_name": "eu-west-1"}
         )
 
     return [filename_and_path, filename_and_path_latest]
@@ -186,16 +198,36 @@ def save(dataset: xr.Dataset, save_dir: str, save_latest: bool = True, output_ty
     # option to save latest or not
     if save_latest:
         logger.debug(f"Saving latest file {filename_and_path_latest}")
+
         if output_type == "zarr":
             dataset.to_zarr(
                 store=filename_and_path_latest, mode="w", encoding=encoding, consolidated=True
             )
         else:
-            dataset.to_netcdf(path=filename_and_path_latest, mode="w", engine="h5netcdf")
+            save_to_netcdf_to_s3(dataset=dataset, filename=filename_and_path_latest)
 
     # save historic data
     logger.debug(f"Saving file {filename_and_path}")
     if output_type == "zarr":
         dataset.to_zarr(store=filename_and_path, mode="w", encoding=encoding, consolidated=True)
     else:
-        dataset.to_netcdf(path=filename_and_path, mode="w", engine="h5netcdf")
+        save_to_netcdf_to_s3(dataset=dataset, filename=filename_and_path)
+
+
+def save_to_netcdf_to_s3(dataset: xr.Dataset, filename: str):
+    """Save xarray to netcdf in s3
+
+    1. Save in temp local dir
+    2. upload to s3
+
+    :param dataset: The Xarray Dataset to be save
+    :param filename: The s3 filname
+    """
+    with tempfile.TemporaryDirectory() as dir:
+        # save locally
+        path = f"{dir}/temp.netcdf"
+        dataset.to_netcdf(path=path, mode="w", engine="h5netcdf")
+
+        # save to s3
+        filesystem = fsspec.open(filename).fs
+        filesystem.put(path, filename)
